@@ -24,7 +24,6 @@
 ;;; Code:
 
 (require 'cl-lib)
-(require 'subr-x) ;; hash-table-keys
 
 (defcustom el-job-ng-max-cores
   (max 1 (- (if (eq system-type 'windows-nt)
@@ -40,15 +39,15 @@ if making too many processes, so capping it can help."
 
 ;;; Subroutines
 
-(defvar el-job-ng--debug-level 0
+(defvar el-job-ng--debug-lvl 0
   "Increase this to 1 or 2 to see more debug messages.")
 
 (defun el-job-ng--dbg (level fmt &rest args)
   "Maybe pass FMT and ARGS to `message'.
-LEVEL is the threshold that `el-job-ng--debug-level' should meet or exceed
+LEVEL is the threshold that `el-job-ng--debug-lvl' should meet or exceed
 to unlock this message."
   (declare (indent 1))
-  (when (<= level el-job-ng--debug-level)
+  (when (<= level el-job-ng--debug-lvl)
     (apply #'message (concat "el-job-ng: " fmt) args)))
 
 (defun el-job-ng--split-evenly (big-list n &optional _)
@@ -169,6 +168,7 @@ with one character of your choosing, such as a dot."
 ;;; Entry point
 
 (defvar el-job-ng--jobs (make-hash-table :test #'eq))
+(defvar el-job-ng--debug-last-splits nil)
 (defvar-local el-job-ng--job-here nil)
 (cl-defstruct (el-job-ng--job (:constructor el-job-ng--make-job)
                               (:copier nil))
@@ -244,6 +244,7 @@ ID can also be passed to these helpers:
       (setf .processes nil)
       (setf .callback callback)
       (setf .outputs nil)
+      (setq el-job-ng--debug-last-splits nil)
       ;; https://github.com/meedstrom/org-node/issues/98
       (with-temp-buffer
         (let* ((print-length nil)
@@ -279,6 +280,7 @@ ID can also be passed to these helpers:
                       "--funcall" "el-job-ng--child-work")))
           (setf .stderr (get-buffer-create (format " *el-job-ng:%s:err*" id) t))
           (with-current-buffer .stderr (erase-buffer))
+          (setq el-job-ng--debug-last-splits input-sets)
           (condition-case err
               (dotimes (i n)
                 (let ((proc (make-process
@@ -300,6 +302,8 @@ ID can also be passed to these helpers:
                             func "\n"
                             (prin1-to-string (pop input-sets)) "\n")
                     (send-region proc (point-min) (point-max))
+                    (when (>= el-job-ng--debug-lvl 2)
+                      (clone-buffer (format "*cloned: %s*" (buffer-name))))
                     (erase-buffer))))
             ;; https://github.com/meedstrom/org-node/issues/75
             (( file-error )
@@ -356,7 +360,7 @@ ID can also be passed to these helpers:
                 (equal event "finished\n"))
            ;; NOTE: No particular buffer should be current now.
            (el-job-ng--handle-finished-child proc buf job)
-           (when (and (= 0 el-job-ng--debug-level)
+           (when (and (= 0 el-job-ng--debug-lvl)
                       (buffer-live-p buf))
              (kill-buffer buf)))
 
@@ -466,14 +470,15 @@ MAX-SECS and MESSAGE as in `el-job-ng-sit-until'."
 (defun el-job-ng-debug-kill-all ()
   "Kill all jobs and forget all metadata."
   (interactive)
-  (mapc #'el-job-ng-kill (hash-table-keys el-job-ng--jobs))
+  (cl-loop for id being each hash-key of el-job-ng--jobs
+           do (el-job-ng-kill id))
   (clrhash el-job-ng--jobs))
 
 (defun el-job-ng-cycle-debug ()
-  "Cycle through values for `el-job-ng--debug-level'."
+  "Cycle through values for `el-job-ng--debug-lvl'."
   (interactive)
-  (message "Variable `el-job-ng--debug-level' set to %d"
-           (setq el-job-ng--debug-level (% (1+ el-job-ng--debug-level) 3))))
+  (message "Variable `el-job-ng--debug-lvl' set to %d"
+           (setq el-job-ng--debug-lvl (% (1+ el-job-ng--debug-lvl) 3))))
 
 (cl-defun el-job-ng-run-sync (&key id
                                    inject-vars
@@ -485,8 +490,8 @@ MAX-SECS and MESSAGE as in `el-job-ng-sit-until'."
   "Like `el-job-ng-run' but synchronous.
 This exists for comparison and debugging.
 
-For ID INJECT-VARS REQUIRE EVAL INPUTS FUNCALL-PER-INPUT CALLBACK,
-see `el-job-ng-run'."
+Arguments are the same as `el-job-ng-run' \(ID, INJECT-VARS, REQUIRE,
+EVAL, INPUTS, FUNCALL-PER-INPUT, CALLBACK)."
   (setq id (or id (abs (random))))
   (let ((job (or (gethash id el-job-ng--jobs)
                  (puthash id (el-job-ng--make-job :id id) el-job-ng--jobs))))
